=======
History
=======

0.1.1 (2023-05-26)
------------------

* Every NetworkObject can have a recorder behavior.
* Netowrk settings accept "index" entry.
* Bug fixes and general improvement.


0.1.0 (2023-03-17)
------------------

* Repository made public.
